package cn.iocoder.yudao.module.bpm.controller.admin.oa;

import cn.iocoder.yudao.framework.common.pojo.CommonResult;
import cn.iocoder.yudao.framework.common.util.object.BeanUtils;
import cn.iocoder.yudao.module.bpm.controller.admin.oa.vo.hire.BpmOAHireCreateReqVO;
import cn.iocoder.yudao.module.bpm.controller.admin.oa.vo.hire.BpmOAHireRespVO;
import cn.iocoder.yudao.module.bpm.dal.dataobject.oa.BpmOAHireDO;
import cn.iocoder.yudao.module.bpm.service.oa.BpmOAHireService;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.tags.Tag;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.validation.Valid;

import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;
import static cn.iocoder.yudao.framework.security.core.util.SecurityFrameworkUtils.getLoginUserId;

/**
 * OA 招聘申请 Controller
 *
 * @author 符溶馨
 */
@Tag(name = "管理后台 - OA 招聘申请")
@RestController
@RequestMapping("/bpm/oa/hire")
@Validated
public class BpmOAHireController {

    @Resource
    private BpmOAHireService bpmOAHireService;

    @PostMapping("/create")
    @Operation(summary = "创建请求申请")
    public CommonResult<Long> createHire(@Valid @RequestBody BpmOAHireCreateReqVO createReqVO) {

        return success(bpmOAHireService.createHire(getLoginUserId(), createReqVO));
    }

    @GetMapping("/get")
    @Operation(summary = "获得招聘申请")
    @Parameter(name = "id", description = "编号", required = true, example = "1024")
    public CommonResult<BpmOAHireRespVO> getHire(@RequestParam("id") Long id) {

        BpmOAHireDO bpmOAHireDO = bpmOAHireService.getHire(id);

        return success(BeanUtils.toBean(bpmOAHireDO, BpmOAHireRespVO.class));
    }

    @GetMapping("/getByProcessInstanceId")
    @Operation(summary = "获得招聘申请")
    @Parameter(name = "processInstanceId", description = "流程实例编号", required = true, example = "1024")
    public CommonResult<BpmOAHireRespVO> getCashByProcessInstanceId(@RequestParam("processInstanceId") String processInstanceId) {

        BpmOAHireDO bpmOAHireDO = bpmOAHireService.getByProcessInstanceId(processInstanceId);

        return success(BeanUtils.toBean(bpmOAHireDO, BpmOAHireRespVO.class));
    }
}
